==> certmanager-model-v1alpha3-6.2.0-sources.jar: io/fabric8/certmanager/api/model/v1alpha3/CAIssuerFluent.java <==
package io.fabric8.certmanager.api.model.v1alpha3;

import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import java.util.function.Predicate;

 /**
  * Generated
  */
public interface CAIssuerFluent<A extends CAIssuerFluent<A>> extends Fluent<A>{
  public A addToCrlDistributionPoints(Integer index,String item);
  public A setToCrlDistributionPoints(Integer index,String item);
  public A addToCrlDistributionPoints(java.lang.String... items);
  public A addAllToCrlDistributionPoints(Collection<String> items);
  public A removeFromCrlDistributionPoints(java.lang.String... items);
  public A removeAllFromCrlDistributionPoints(Collection<String> items);
  public List<String> getCrlDistributionPoints();
  public String getCrlDistributionPoint(Integer index);
  public String getFirstCrlDistributionPoint();
  public String getLastCrlDistributionPoint();
  public String getMatchingCrlDistributionPoint(Predicate<String> predicate);
  public Boolean hasMatchingCrlDistributionPoint(Predicate<String> predicate);
  public A withCrlDistributionPoints(List<String> crlDistributionPoints);
  public A withCrlDistributionPoints(java.lang.String... crlDistributionPoints);
  public Boolean hasCrlDistributionPoints();
  public A addToOcspServers(Integer index,String item);
  public A setToOcspServers(Integer index,String item);
  public A addToOcspServers(java.lang.String... items);
  public A addAllToOcspServers(Collection<String> items);
  public A removeFromOcspServers(java.lang.String... items);
  public A removeAllFromOcspServers(Collection<String> items);
  public List<String> getOcspServers();
  public String getOcspServer(Integer index);
  public String getFirstOcspServer();
  public String getLastOcspServer();
  public String getMatchingOcspServer(Predicate<String> predicate);
  public Boolean hasMatchingOcspServer(Predicate<String> predicate);
  public A withOcspServers(List<String> ocspServers);
  public A withOcspServers(java.lang.String... ocspServers);
  public Boolean hasOcspServers();
  public String getSecretName();
  public A withSecretName(String secretName);
  public Boolean hasSecretName();
  
}

==> certmanager-model-v1alpha3-6.7.2-sources.jar: io/fabric8/certmanager/api/model/v1alpha3/CAIssuerFluent.java <==
package io.fabric8.certmanager.api.model.v1alpha3;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import java.util.function.Predicate;

 /**
  * Generated
  */
public interface CAIssuerFluent<A extends CAIssuerFluent<A>> extends Fluent<A>{
  public A addToCrlDistributionPoints(int index,String item);
  public A setToCrlDistributionPoints(int index,String item);
  public A addToCrlDistributionPoints(java.lang.String... items);
  public A addAllToCrlDistributionPoints(Collection<String> items);
  public A removeFromCrlDistributionPoints(java.lang.String... items);
  public A removeAllFromCrlDistributionPoints(Collection<String> items);
  public List<String> getCrlDistributionPoints();
  public String getCrlDistributionPoint(int index);
  public String getFirstCrlDistributionPoint();
  public String getLastCrlDistributionPoint();
  public String getMatchingCrlDistributionPoint(Predicate<String> predicate);
  public Boolean hasMatchingCrlDistributionPoint(Predicate<String> predicate);
  public A withCrlDistributionPoints(List<String> crlDistributionPoints);
  public A withCrlDistributionPoints(java.lang.String... crlDistributionPoints);
  public Boolean hasCrlDistributionPoints();
  public A addToOcspServers(int index,String item);
  public A setToOcspServers(int index,String item);
  public A addToOcspServers(java.lang.String... items);
  public A addAllToOcspServers(Collection<String> items);
  public A removeFromOcspServers(java.lang.String... items);
  public A removeAllFromOcspServers(Collection<String> items);
  public List<String> getOcspServers();
  public String getOcspServer(int index);
  public String getFirstOcspServer();
  public String getLastOcspServer();
  public String getMatchingOcspServer(Predicate<String> predicate);
  public Boolean hasMatchingOcspServer(Predicate<String> predicate);
  public A withOcspServers(List<String> ocspServers);
  public A withOcspServers(java.lang.String... ocspServers);
  public Boolean hasOcspServers();
  public String getSecretName();
  public A withSecretName(String secretName);
  public Boolean hasSecretName();
  
}
